@@ -93,7 +93,7 @@ public:
     ~PartMan();
     void scan(Device *drvstart = nullptr);
     void scanVirtualDevices(bool rescan);
-    void scanSubvolumes(class Device *part);
+    void scanSubvolumes(class Device *part, const QString &scratch = QString());
     bool loadConfig(class MSettings &config) noexcept;
     void saveConfig(class MSettings &config) const noexcept;
     bool validate(bool automatic, QTreeWidgetItem *confroot = nullptr) const noexcept;
@@ -206,6 +206,11 @@ public:
 
     Device(enum DeviceType type, Device *parent, Device *preceding = nullptr) noexcept;
     ~Device();
+    // Copy and move constructors will cause dangling pointers here.
+    Device(const Device &) = delete;
+    Device &operator=(const Device &) = delete;
+    Device(Device &&) = delete;
+
     void clear() noexcept;
     int row() const noexcept;
     Device *parent() const noexcept;
@@ -238,7 +243,7 @@ public:
     bool canMount(bool fsonly = true) const noexcept;
     long long driveFreeSpace(bool inclusive = false) const noexcept;
     /* Convenience */
-    QString friendlyName() const noexcept;
+    QString friendlyName(bool mappedFormat = false) const noexcept;
     void addToCombo(QComboBox *combo, bool warnNasty = false) const noexcept;
 
 private:
@@ -255,11 +260,12 @@ private:
 
 class PartMan::Iterator
 {
+    Device *start = nullptr;
     Device *pos = nullptr;
     int ixPos = 0;
     std::stack<int, std::vector<int>> ixParents;
 public:
-    Iterator(Device *device) noexcept : pos(device) {}
+    Iterator(Device *device) noexcept : start(device), pos(device) {}
     Iterator(const PartMan &partman) noexcept;
     inline Device *operator*() const noexcept { return pos; }
     void next() noexcept;
